Package: paws.developer.tools
Title: 'Amazon Web Services' Developer Tools Services
Version: 0.10.0
Authors@R: c(
    person("David", "Kretch", , "david.kretch@gmail.com", role = "aut"),
    person("Adam", "Banker", , "adam.banker39@gmail.com", role = "aut"),
    person("Dyfan", "Jones", , "dyfan.r.jones@gmail.com", role = "cre"),
    person("Amazon.com, Inc.", role = "cph")
  )
Description: Interface to 'Amazon Web Services' developer tools services,
    including version control, continuous integration and deployment, and
    more <https://aws.amazon.com/products/developer-tools/>.
License: Apache License (>= 2.0)
URL: https://github.com/paws-r/paws,
        https://paws-r.r-universe.dev/paws.developer.tools,
        https://www.paws-r-sdk.com
BugReports: https://github.com/paws-r/paws/issues
Imports: paws.common (>= 0.8.0)
Suggests: testthat
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
Collate: 'cloud9_service.R' 'cloud9_interfaces.R' 'cloud9_operations.R'
        'cloudcontrolapi_service.R' 'cloudcontrolapi_interfaces.R'
        'cloudcontrolapi_operations.R' 'codeartifact_service.R'
        'codeartifact_interfaces.R' 'codeartifact_operations.R'
        'codebuild_service.R' 'codebuild_interfaces.R'
        'codebuild_operations.R' 'codecatalyst_service.R'
        'codecatalyst_interfaces.R' 'codecatalyst_operations.R'
        'codecommit_service.R' 'codecommit_interfaces.R'
        'codecommit_operations.R' 'codeconnections_service.R'
        'codeconnections_interfaces.R' 'codeconnections_operations.R'
        'codedeploy_service.R' 'codedeploy_interfaces.R'
        'codedeploy_operations.R' 'codeguruprofiler_service.R'
        'codeguruprofiler_interfaces.R' 'codeguruprofiler_operations.R'
        'codegurureviewer_service.R' 'codegurureviewer_interfaces.R'
        'codegurureviewer_operations.R' 'codegurusecurity_service.R'
        'codegurusecurity_interfaces.R' 'codegurusecurity_operations.R'
        'codepipeline_service.R' 'codepipeline_interfaces.R'
        'codepipeline_operations.R' 'codestarconnections_service.R'
        'codestarconnections_interfaces.R'
        'codestarconnections_operations.R'
        'codestarnotifications_service.R'
        'codestarnotifications_interfaces.R'
        'codestarnotifications_operations.R' 'devopsguru_service.R'
        'devopsguru_interfaces.R' 'devopsguru_operations.R'
        'drs_service.R' 'drs_interfaces.R' 'drs_operations.R'
        'fis_service.R' 'fis_interfaces.R' 'fis_operations.R'
        'reexports_paws.common.R' 'wellarchitected_service.R'
        'wellarchitected_interfaces.R' 'wellarchitected_operations.R'
        'xray_service.R' 'xray_interfaces.R' 'xray_operations.R'
NeedsCompilation: no
Packaged: 2026-05-29 17:21:54 UTC; dyfan
Author: David Kretch [aut],
  Adam Banker [aut],
  Dyfan Jones [cre],
  Amazon.com, Inc. [cph]
Maintainer: Dyfan Jones <dyfan.r.jones@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-30 05:11:25 UTC
Built: R 4.6.0; ; 2026-05-30 05:42:29 UTC; unix
