# Generated by roxygen2: do not edit by hand

export(cloud9)
export(cloudcontrolapi)
export(codeartifact)
export(codebuild)
export(codecatalyst)
export(codecommit)
export(codeconnections)
export(codedeploy)
export(codeguruprofiler)
export(codegurureviewer)
export(codegurusecurity)
export(codepipeline)
export(codestarconnections)
export(codestarnotifications)
export(config)
export(credentials)
export(creds)
export(devopsguru)
export(drs)
export(fis)
export(list_paginators)
export(paginate)
export(paginate_lapply)
export(paginate_sapply)
export(paws_stream_parser)
export(wellarchitected)
export(xray)
importFrom(paws.common,config)
importFrom(paws.common,credentials)
importFrom(paws.common,creds)
importFrom(paws.common,get_config)
importFrom(paws.common,list_paginators)
importFrom(paws.common,merge_config)
importFrom(paws.common,new_handlers)
importFrom(paws.common,new_operation)
importFrom(paws.common,new_request)
importFrom(paws.common,new_service)
importFrom(paws.common,paginate)
importFrom(paws.common,paginate_lapply)
importFrom(paws.common,paginate_sapply)
importFrom(paws.common,paws_stream_parser)
importFrom(paws.common,populate)
importFrom(paws.common,send_request)
importFrom(paws.common,set_config)
