# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common populate
#' @include codecommit_service.R
NULL

.codecommit$associate_approval_rule_template_with_repository_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$associate_approval_rule_template_with_repository_output <- function(...) {
  list()
}

.codecommit$batch_associate_approval_rule_template_with_repositories_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), repositoryNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_associate_approval_rule_template_with_repositories_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(associatedRepositoryNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), errors = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), errorCode = structure(logical(0), tags = list(type = "string")), errorMessage = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_describe_merge_conflicts_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string")), maxMergeHunks = structure(logical(0), tags = list(type = "integer")), maxConflictFiles = structure(logical(0), tags = list(type = "integer")), filePaths = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_describe_merge_conflicts_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(conflicts = structure(list(structure(list(conflictMetadata = structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileSizes = structure(list(source = structure(logical(0), tags = list(type = "long")), destination = structure(logical(0), tags = list(type = "long")), base = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), fileModes = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string")), base = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), objectTypes = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string")), base = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), numberOfConflicts = structure(logical(0), tags = list(type = "integer")), isBinaryFile = structure(list(source = structure(logical(0), tags = list(type = "boolean")), destination = structure(logical(0), tags = list(type = "boolean")), base = structure(logical(0), tags = list(type = "boolean"))), tags = list(type = "structure")), contentConflict = structure(logical(0), tags = list(type = "boolean")), fileModeConflict = structure(logical(0), tags = list(type = "boolean")), objectTypeConflict = structure(logical(0), tags = list(type = "boolean")), mergeOperations = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), mergeHunks = structure(list(structure(list(isConflict = structure(logical(0), tags = list(type = "boolean")), source = structure(list(startLine = structure(logical(0), tags = list(type = "integer")), endLine = structure(logical(0), tags = list(type = "integer")), hunkContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), destination = structure(list(startLine = structure(logical(0), tags = list(type = "integer")), endLine = structure(logical(0), tags = list(type = "integer")), hunkContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), base = structure(list(startLine = structure(logical(0), tags = list(type = "integer")), endLine = structure(logical(0), tags = list(type = "integer")), hunkContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string")), errors = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), exceptionName = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), destinationCommitId = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string")), baseCommitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_disassociate_approval_rule_template_from_repositories_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), repositoryNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_disassociate_approval_rule_template_from_repositories_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(disassociatedRepositoryNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), errors = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), errorCode = structure(logical(0), tags = list(type = "string")), errorMessage = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_get_commits_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), repositoryName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_get_commits_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commits = structure(list(structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string")), parents = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), message = structure(logical(0), tags = list(type = "string")), author = structure(list(name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), date = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), committer = structure(list(name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), date = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), additionalData = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), errors = structure(list(structure(list(commitId = structure(logical(0), tags = list(type = "string")), errorCode = structure(logical(0), tags = list(type = "string")), errorMessage = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_get_repositories_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$batch_get_repositories_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositories = structure(list(structure(list(accountId = structure(logical(0), tags = list(type = "string")), repositoryId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), repositoryDescription = structure(logical(0), tags = list(type = "string")), defaultBranch = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), cloneUrlHttp = structure(logical(0), tags = list(type = "string")), cloneUrlSsh = structure(logical(0), tags = list(type = "string")), Arn = structure(logical(0), tags = list(type = "string")), kmsKeyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), repositoriesNotFound = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), errors = structure(list(structure(list(repositoryId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), errorCode = structure(logical(0), tags = list(type = "string")), errorMessage = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_approval_rule_template_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateContent = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_approval_rule_template_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_branch_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), branchName = structure(logical(0), tags = list(type = "string")), commitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_branch_output <- function(...) {
  list()
}

.codecommit$create_commit_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), branchName = structure(logical(0), tags = list(type = "string")), parentCommitId = structure(logical(0), tags = list(type = "string")), authorName = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), putFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string")), fileContent = structure(logical(0), tags = list(type = "blob")), sourceFile = structure(list(filePath = structure(logical(0), tags = list(type = "string")), isMove = structure(logical(0), tags = list(type = "boolean"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), deleteFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), setFileModes = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_commit_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string")), filesAdded = structure(list(structure(list(absolutePath = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), filesUpdated = structure(list(structure(list(absolutePath = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), filesDeleted = structure(list(structure(list(absolutePath = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_pull_request_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), targets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_pull_request_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_pull_request_approval_rule_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_pull_request_approval_rule_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRule = structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_repository_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), repositoryDescription = structure(logical(0), tags = list(type = "string")), tags = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), kmsKeyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_repository_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryMetadata = structure(list(accountId = structure(logical(0), tags = list(type = "string")), repositoryId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), repositoryDescription = structure(logical(0), tags = list(type = "string")), defaultBranch = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), cloneUrlHttp = structure(logical(0), tags = list(type = "string")), cloneUrlSsh = structure(logical(0), tags = list(type = "string")), Arn = structure(logical(0), tags = list(type = "string")), kmsKeyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_unreferenced_merge_commit_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), authorName = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), conflictResolution = structure(list(replaceContents = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), replacementType = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "blob")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), deleteFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), setFileModes = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$create_unreferenced_merge_commit_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_approval_rule_template_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_approval_rule_template_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_branch_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), branchName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_branch_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(deletedBranch = structure(list(branchName = structure(logical(0), tags = list(type = "string")), commitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_comment_content_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_comment_content_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(comment = structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_file_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), branchName = structure(logical(0), tags = list(type = "string")), filePath = structure(logical(0), tags = list(type = "string")), parentCommitId = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), commitMessage = structure(logical(0), tags = list(type = "string")), name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_file_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string")), filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_pull_request_approval_rule_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_pull_request_approval_rule_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_repository_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$delete_repository_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$describe_merge_conflicts_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string")), maxMergeHunks = structure(logical(0), tags = list(type = "integer")), filePath = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$describe_merge_conflicts_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(conflictMetadata = structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileSizes = structure(list(source = structure(logical(0), tags = list(type = "long")), destination = structure(logical(0), tags = list(type = "long")), base = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), fileModes = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string")), base = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), objectTypes = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string")), base = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), numberOfConflicts = structure(logical(0), tags = list(type = "integer")), isBinaryFile = structure(list(source = structure(logical(0), tags = list(type = "boolean")), destination = structure(logical(0), tags = list(type = "boolean")), base = structure(logical(0), tags = list(type = "boolean"))), tags = list(type = "structure")), contentConflict = structure(logical(0), tags = list(type = "boolean")), fileModeConflict = structure(logical(0), tags = list(type = "boolean")), objectTypeConflict = structure(logical(0), tags = list(type = "boolean")), mergeOperations = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), mergeHunks = structure(list(structure(list(isConflict = structure(logical(0), tags = list(type = "boolean")), source = structure(list(startLine = structure(logical(0), tags = list(type = "integer")), endLine = structure(logical(0), tags = list(type = "integer")), hunkContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), destination = structure(list(startLine = structure(logical(0), tags = list(type = "integer")), endLine = structure(logical(0), tags = list(type = "integer")), hunkContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), base = structure(list(startLine = structure(logical(0), tags = list(type = "integer")), endLine = structure(logical(0), tags = list(type = "integer")), hunkContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string")), destinationCommitId = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string")), baseCommitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$describe_pull_request_events_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), pullRequestEventType = structure(logical(0), tags = list(type = "string")), actorArn = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$describe_pull_request_events_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestEvents = structure(list(structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), eventDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestEventType = structure(logical(0), tags = list(type = "string")), actorArn = structure(logical(0), tags = list(type = "string")), pullRequestCreatedEventMetadata = structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string")), destinationCommitId = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), pullRequestStatusChangedEventMetadata = structure(list(pullRequestStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), pullRequestSourceReferenceUpdatedEventMetadata = structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), pullRequestMergedStateChangedEventMetadata = structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), approvalRuleEventMetadata = structure(list(approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), approvalStateChangedEventMetadata = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), approvalStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), approvalRuleOverriddenEventMetadata = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), overrideStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$disassociate_approval_rule_template_from_repository_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$disassociate_approval_rule_template_from_repository_output <- function(...) {
  list()
}

.codecommit$evaluate_pull_request_approval_rules_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$evaluate_pull_request_approval_rules_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(evaluation = structure(list(approved = structure(logical(0), tags = list(type = "boolean")), overridden = structure(logical(0), tags = list(type = "boolean")), approvalRulesSatisfied = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), approvalRulesNotSatisfied = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_approval_rule_template_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_approval_rule_template_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_blob_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_blob_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(content = structure(logical(0), tags = list(type = "blob"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_branch_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), branchName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_branch_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(branch = structure(list(branchName = structure(logical(0), tags = list(type = "string")), commitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comment_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comment_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(comment = structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comment_reactions_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentId = structure(logical(0), tags = list(type = "string")), reactionUserArn = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comment_reactions_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(reactionsForComment = structure(list(structure(list(reaction = structure(list(emoji = structure(logical(0), tags = list(type = "string")), shortCode = structure(logical(0), tags = list(type = "string")), unicode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), reactionUsers = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionsFromDeletedUsersCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comments_for_compared_commit_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comments_for_compared_commit_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentsForComparedCommitData = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), beforeBlobId = structure(logical(0), tags = list(type = "string")), afterBlobId = structure(logical(0), tags = list(type = "string")), location = structure(list(filePath = structure(logical(0), tags = list(type = "string")), filePosition = structure(logical(0), tags = list(type = "long")), relativeFileVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), comments = structure(list(structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comments_for_pull_request_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_comments_for_pull_request_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentsForPullRequestData = structure(list(structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), beforeBlobId = structure(logical(0), tags = list(type = "string")), afterBlobId = structure(logical(0), tags = list(type = "string")), location = structure(list(filePath = structure(logical(0), tags = list(type = "string")), filePosition = structure(logical(0), tags = list(type = "long")), relativeFileVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), comments = structure(list(structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_commit_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), commitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_commit_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commit = structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string")), parents = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), message = structure(logical(0), tags = list(type = "string")), author = structure(list(name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), date = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), committer = structure(list(name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), date = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), additionalData = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_differences_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitSpecifier = structure(logical(0), tags = list(type = "string")), afterCommitSpecifier = structure(logical(0), tags = list(type = "string")), beforePath = structure(logical(0), tags = list(type = "string")), afterPath = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_differences_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(differences = structure(list(structure(list(beforeBlob = structure(list(blobId = structure(logical(0), tags = list(type = "string")), path = structure(logical(0), tags = list(type = "string")), mode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), afterBlob = structure(list(blobId = structure(logical(0), tags = list(type = "string")), path = structure(logical(0), tags = list(type = "string")), mode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), changeType = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_file_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), commitSpecifier = structure(logical(0), tags = list(type = "string")), filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_file_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string")), filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string")), fileSize = structure(logical(0), tags = list(type = "long")), fileContent = structure(logical(0), tags = list(type = "blob"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_folder_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), commitSpecifier = structure(logical(0), tags = list(type = "string")), folderPath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_folder_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), folderPath = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string")), subFolders = structure(list(structure(list(treeId = structure(logical(0), tags = list(type = "string")), absolutePath = structure(logical(0), tags = list(type = "string")), relativePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), files = structure(list(structure(list(blobId = structure(logical(0), tags = list(type = "string")), absolutePath = structure(logical(0), tags = list(type = "string")), relativePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), symbolicLinks = structure(list(structure(list(blobId = structure(logical(0), tags = list(type = "string")), absolutePath = structure(logical(0), tags = list(type = "string")), relativePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), subModules = structure(list(structure(list(commitId = structure(logical(0), tags = list(type = "string")), absolutePath = structure(logical(0), tags = list(type = "string")), relativePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_merge_commit_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_merge_commit_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(sourceCommitId = structure(logical(0), tags = list(type = "string")), destinationCommitId = structure(logical(0), tags = list(type = "string")), baseCommitId = structure(logical(0), tags = list(type = "string")), mergedCommitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_merge_conflicts_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), maxConflictFiles = structure(logical(0), tags = list(type = "integer")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_merge_conflicts_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(mergeable = structure(logical(0), tags = list(type = "boolean")), destinationCommitId = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string")), baseCommitId = structure(logical(0), tags = list(type = "string")), conflictMetadataList = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileSizes = structure(list(source = structure(logical(0), tags = list(type = "long")), destination = structure(logical(0), tags = list(type = "long")), base = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), fileModes = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string")), base = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), objectTypes = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string")), base = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), numberOfConflicts = structure(logical(0), tags = list(type = "integer")), isBinaryFile = structure(list(source = structure(logical(0), tags = list(type = "boolean")), destination = structure(logical(0), tags = list(type = "boolean")), base = structure(logical(0), tags = list(type = "boolean"))), tags = list(type = "structure")), contentConflict = structure(logical(0), tags = list(type = "boolean")), fileModeConflict = structure(logical(0), tags = list(type = "boolean")), objectTypeConflict = structure(logical(0), tags = list(type = "boolean")), mergeOperations = structure(list(source = structure(logical(0), tags = list(type = "string")), destination = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_merge_options_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_merge_options_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(mergeOptions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), sourceCommitId = structure(logical(0), tags = list(type = "string")), destinationCommitId = structure(logical(0), tags = list(type = "string")), baseCommitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_pull_request_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_pull_request_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_pull_request_approval_states_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_pull_request_approval_states_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvals = structure(list(structure(list(userArn = structure(logical(0), tags = list(type = "string")), approvalState = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_pull_request_override_state_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_pull_request_override_state_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(overridden = structure(logical(0), tags = list(type = "boolean")), overrider = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_repository_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_repository_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryMetadata = structure(list(accountId = structure(logical(0), tags = list(type = "string")), repositoryId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), repositoryDescription = structure(logical(0), tags = list(type = "string")), defaultBranch = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), cloneUrlHttp = structure(logical(0), tags = list(type = "string")), cloneUrlSsh = structure(logical(0), tags = list(type = "string")), Arn = structure(logical(0), tags = list(type = "string")), kmsKeyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_repository_triggers_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$get_repository_triggers_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(configurationId = structure(logical(0), tags = list(type = "string")), triggers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), destinationArn = structure(logical(0), tags = list(type = "string")), customData = structure(logical(0), tags = list(type = "string")), branches = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_approval_rule_templates_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_approval_rule_templates_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_associated_approval_rule_templates_for_repository_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_associated_approval_rule_templates_for_repository_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_branches_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_branches_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(branches = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_file_commit_history_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), commitSpecifier = structure(logical(0), tags = list(type = "string")), filePath = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer", box = TRUE)), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_file_commit_history_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(revisionDag = structure(list(structure(list(commit = structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string")), parents = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), message = structure(logical(0), tags = list(type = "string")), author = structure(list(name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), date = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), committer = structure(list(name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), date = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), additionalData = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), blobId = structure(logical(0), tags = list(type = "string")), path = structure(logical(0), tags = list(type = "string")), revisionChildren = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_pull_requests_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_pull_requests_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_repositories_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(nextToken = structure(logical(0), tags = list(type = "string")), sortBy = structure(logical(0), tags = list(type = "string")), order = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_repositories_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositories = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), repositoryId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_repositories_for_approval_rule_template_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_repositories_for_approval_rule_template_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_tags_for_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(resourceArn = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$list_tags_for_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(tags = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_branches_by_fast_forward_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), targetBranch = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_branches_by_fast_forward_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_branches_by_squash_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), targetBranch = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), authorName = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), conflictResolution = structure(list(replaceContents = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), replacementType = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "blob")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), deleteFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), setFileModes = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_branches_by_squash_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_branches_by_three_way_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitSpecifier = structure(logical(0), tags = list(type = "string")), destinationCommitSpecifier = structure(logical(0), tags = list(type = "string")), targetBranch = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), authorName = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), conflictResolution = structure(list(replaceContents = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), replacementType = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "blob")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), deleteFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), setFileModes = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_branches_by_three_way_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_pull_request_by_fast_forward_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_pull_request_by_fast_forward_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_pull_request_by_squash_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), authorName = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), conflictResolution = structure(list(replaceContents = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), replacementType = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "blob")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), deleteFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), setFileModes = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_pull_request_by_squash_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_pull_request_by_three_way_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), sourceCommitId = structure(logical(0), tags = list(type = "string")), conflictDetailLevel = structure(logical(0), tags = list(type = "string")), conflictResolutionStrategy = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), authorName = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string")), keepEmptyFolders = structure(logical(0), tags = list(type = "boolean")), conflictResolution = structure(list(replaceContents = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), replacementType = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "blob")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), deleteFiles = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), setFileModes = structure(list(structure(list(filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$merge_pull_request_by_three_way_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$override_pull_request_approval_rules_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), overrideStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$override_pull_request_approval_rules_output <- function(...) {
  list()
}

.codecommit$post_comment_for_compared_commit_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), location = structure(list(filePath = structure(logical(0), tags = list(type = "string")), filePosition = structure(logical(0), tags = list(type = "long")), relativeFileVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), content = structure(logical(0), tags = list(type = "string")), clientRequestToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$post_comment_for_compared_commit_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), beforeBlobId = structure(logical(0), tags = list(type = "string")), afterBlobId = structure(logical(0), tags = list(type = "string")), location = structure(list(filePath = structure(logical(0), tags = list(type = "string")), filePosition = structure(logical(0), tags = list(type = "long")), relativeFileVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), comment = structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$post_comment_for_pull_request_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), repositoryName = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), location = structure(list(filePath = structure(logical(0), tags = list(type = "string")), filePosition = structure(logical(0), tags = list(type = "long")), relativeFileVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), content = structure(logical(0), tags = list(type = "string")), clientRequestToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$post_comment_for_pull_request_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), pullRequestId = structure(logical(0), tags = list(type = "string")), beforeCommitId = structure(logical(0), tags = list(type = "string")), afterCommitId = structure(logical(0), tags = list(type = "string")), beforeBlobId = structure(logical(0), tags = list(type = "string")), afterBlobId = structure(logical(0), tags = list(type = "string")), location = structure(list(filePath = structure(logical(0), tags = list(type = "string")), filePosition = structure(logical(0), tags = list(type = "long")), relativeFileVersion = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), comment = structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$post_comment_reply_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(inReplyTo = structure(logical(0), tags = list(type = "string")), clientRequestToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string")), content = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$post_comment_reply_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(comment = structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$put_comment_reaction_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentId = structure(logical(0), tags = list(type = "string")), reactionValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$put_comment_reaction_output <- function(...) {
  list()
}

.codecommit$put_file_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), branchName = structure(logical(0), tags = list(type = "string")), fileContent = structure(logical(0), tags = list(type = "blob")), filePath = structure(logical(0), tags = list(type = "string")), fileMode = structure(logical(0), tags = list(type = "string")), parentCommitId = structure(logical(0), tags = list(type = "string")), commitMessage = structure(logical(0), tags = list(type = "string")), name = structure(logical(0), tags = list(type = "string")), email = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$put_file_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commitId = structure(logical(0), tags = list(type = "string")), blobId = structure(logical(0), tags = list(type = "string")), treeId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$put_repository_triggers_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), triggers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), destinationArn = structure(logical(0), tags = list(type = "string")), customData = structure(logical(0), tags = list(type = "string")), branches = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$put_repository_triggers_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(configurationId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$tag_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(resourceArn = structure(logical(0), tags = list(type = "string")), tags = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$tag_resource_output <- function(...) {
  list()
}

.codecommit$test_repository_triggers_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), triggers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), destinationArn = structure(logical(0), tags = list(type = "string")), customData = structure(logical(0), tags = list(type = "string")), branches = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$test_repository_triggers_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(successfulExecutions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), failedExecutions = structure(list(structure(list(trigger = structure(logical(0), tags = list(type = "string")), failureMessage = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$untag_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(resourceArn = structure(logical(0), tags = list(type = "string")), tagKeys = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$untag_resource_output <- function(...) {
  list()
}

.codecommit$update_approval_rule_template_content_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), newRuleContent = structure(logical(0), tags = list(type = "string")), existingRuleContentSha256 = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_approval_rule_template_content_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_approval_rule_template_description_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_approval_rule_template_description_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_approval_rule_template_name_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(oldApprovalRuleTemplateName = structure(logical(0), tags = list(type = "string")), newApprovalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_approval_rule_template_name_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateDescription = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_comment_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_comment_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(comment = structure(list(commentId = structure(logical(0), tags = list(type = "string")), content = structure(logical(0), tags = list(type = "string")), inReplyTo = structure(logical(0), tags = list(type = "string")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), authorArn = structure(logical(0), tags = list(type = "string")), deleted = structure(logical(0), tags = list(type = "boolean")), clientRequestToken = structure(logical(0), tags = list(type = "string")), callerReactions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), reactionCounts = structure(list(structure(logical(0), tags = list(type = "integer"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_default_branch_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), defaultBranchName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_default_branch_output <- function(...) {
  list()
}

.codecommit$update_pull_request_approval_rule_content_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), existingRuleContentSha256 = structure(logical(0), tags = list(type = "string")), newRuleContent = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_approval_rule_content_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvalRule = structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_approval_state_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalState = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_approval_state_output <- function(...) {
  list()
}

.codecommit$update_pull_request_description_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_description_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_status_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), pullRequestStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_status_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_title_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_pull_request_title_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pullRequest = structure(list(pullRequestId = structure(logical(0), tags = list(type = "string")), title = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string")), lastActivityDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), pullRequestStatus = structure(logical(0), tags = list(type = "string")), authorArn = structure(logical(0), tags = list(type = "string")), pullRequestTargets = structure(list(structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), sourceReference = structure(logical(0), tags = list(type = "string")), destinationReference = structure(logical(0), tags = list(type = "string")), destinationCommit = structure(logical(0), tags = list(type = "string")), sourceCommit = structure(logical(0), tags = list(type = "string")), mergeBase = structure(logical(0), tags = list(type = "string")), mergeMetadata = structure(list(isMerged = structure(logical(0), tags = list(type = "boolean")), mergedBy = structure(logical(0), tags = list(type = "string")), mergeCommitId = structure(logical(0), tags = list(type = "string")), mergeOption = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), approvalRules = structure(list(structure(list(approvalRuleId = structure(logical(0), tags = list(type = "string")), approvalRuleName = structure(logical(0), tags = list(type = "string")), approvalRuleContent = structure(logical(0), tags = list(type = "string")), ruleContentSha256 = structure(logical(0), tags = list(type = "string")), lastModifiedDate = structure(logical(0), tags = list(type = "timestamp")), creationDate = structure(logical(0), tags = list(type = "timestamp")), lastModifiedUser = structure(logical(0), tags = list(type = "string")), originApprovalRuleTemplate = structure(list(approvalRuleTemplateId = structure(logical(0), tags = list(type = "string")), approvalRuleTemplateName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_repository_description_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), repositoryDescription = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_repository_description_output <- function(...) {
  list()
}

.codecommit$update_repository_encryption_key_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryName = structure(logical(0), tags = list(type = "string")), kmsKeyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_repository_encryption_key_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(repositoryId = structure(logical(0), tags = list(type = "string")), kmsKeyId = structure(logical(0), tags = list(type = "string")), originalKmsKeyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_repository_name_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(oldName = structure(logical(0), tags = list(type = "string")), newName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codecommit$update_repository_name_output <- function(...) {
  list()
}
