# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common populate
#' @include devopsguru_service.R
NULL

.devopsguru$add_notification_channel_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Config = structure(list(Sns = structure(list(TopicArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), Filters = structure(list(Severities = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), MessageTypes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$add_notification_channel_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Id = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$delete_insight_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Id = structure(logical(0), tags = list(location = "uri", locationName = "Id", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$delete_insight_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_account_health_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_account_health_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(OpenReactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), MetricsAnalyzed = structure(logical(0), tags = list(type = "integer")), ResourceHours = structure(logical(0), tags = list(type = "long")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_account_overview_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_account_overview_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ReactiveInsights = structure(logical(0), tags = list(type = "integer")), ProactiveInsights = structure(logical(0), tags = list(type = "integer")), MeanTimeToRecoverInMilliseconds = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_anomaly_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Id = structure(logical(0), tags = list(location = "uri", locationName = "Id", type = "string")), AccountId = structure(logical(0), tags = list(location = "querystring", locationName = "AccountId", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_anomaly_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveAnomaly = structure(list(Id = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), UpdateTime = structure(logical(0), tags = list(type = "timestamp")), AnomalyTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), AnomalyReportedTimeRange = structure(list(OpenTime = structure(logical(0), tags = list(type = "timestamp")), CloseTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), SourceDetails = structure(list(CloudWatchMetrics = structure(list(structure(list(MetricName = structure(logical(0), tags = list(type = "string")), Namespace = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Stat = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), Period = structure(logical(0), tags = list(type = "integer")), MetricDataSummary = structure(list(TimestampMetricValuePairList = structure(list(structure(list(Timestamp = structure(logical(0), tags = list(type = "timestamp")), MetricValue = structure(logical(0), tags = list(type = "double"))), tags = list(type = "structure"))), tags = list(type = "list")), StatusCode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), PerformanceInsightsMetrics = structure(list(structure(list(MetricDisplayName = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), ReferenceData = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), ComparisonValues = structure(list(ReferenceScalar = structure(list(Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure")), ReferenceMetric = structure(list(MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtAnomaly = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtBaseline = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedInsightId = structure(logical(0), tags = list(type = "string")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), Limit = structure(logical(0), tags = list(type = "double", box = TRUE)), SourceMetadata = structure(list(Source = structure(logical(0), tags = list(type = "string")), SourceResourceName = structure(logical(0), tags = list(type = "string")), SourceResourceType = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), AnomalyResources = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), ReactiveAnomaly = structure(list(Id = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), AnomalyTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), AnomalyReportedTimeRange = structure(list(OpenTime = structure(logical(0), tags = list(type = "timestamp")), CloseTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), SourceDetails = structure(list(CloudWatchMetrics = structure(list(structure(list(MetricName = structure(logical(0), tags = list(type = "string")), Namespace = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Stat = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), Period = structure(logical(0), tags = list(type = "integer")), MetricDataSummary = structure(list(TimestampMetricValuePairList = structure(list(structure(list(Timestamp = structure(logical(0), tags = list(type = "timestamp")), MetricValue = structure(logical(0), tags = list(type = "double"))), tags = list(type = "structure"))), tags = list(type = "list")), StatusCode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), PerformanceInsightsMetrics = structure(list(structure(list(MetricDisplayName = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), ReferenceData = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), ComparisonValues = structure(list(ReferenceScalar = structure(list(Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure")), ReferenceMetric = structure(list(MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtAnomaly = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtBaseline = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedInsightId = structure(logical(0), tags = list(type = "string")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), Type = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Description = structure(logical(0), tags = list(type = "string")), CausalAnomalyId = structure(logical(0), tags = list(type = "string")), AnomalyResources = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_event_sources_config_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_event_sources_config_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(EventSources = structure(list(AmazonCodeGuruProfiler = structure(list(Status = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_feedback_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_feedback_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightFeedback = structure(list(Id = structure(logical(0), tags = list(type = "string")), Feedback = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_insight_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Id = structure(logical(0), tags = list(location = "uri", locationName = "Id", type = "string")), AccountId = structure(logical(0), tags = list(location = "querystring", locationName = "AccountId", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_insight_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveInsight = structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), SsmOpsItemId = structure(logical(0), tags = list(type = "string")), Description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), ReactiveInsight = structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), SsmOpsItemId = structure(logical(0), tags = list(type = "string")), Description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_organization_health_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(AccountIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), OrganizationalUnitIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_organization_health_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(OpenReactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), MetricsAnalyzed = structure(logical(0), tags = list(type = "integer")), ResourceHours = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_organization_overview_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp")), AccountIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), OrganizationalUnitIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_organization_overview_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ReactiveInsights = structure(logical(0), tags = list(type = "integer")), ProactiveInsights = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_organization_resource_collection_health_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(OrganizationResourceCollectionType = structure(logical(0), tags = list(type = "string")), AccountIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), OrganizationalUnitIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_organization_resource_collection_health_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CloudFormation = structure(list(structure(list(StackName = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer")), MeanTimeToRecoverInMilliseconds = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))), tags = list(type = "list")), Service = structure(list(structure(list(ServiceName = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))), tags = list(type = "list")), Account = structure(list(structure(list(AccountId = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer")), MeanTimeToRecoverInMilliseconds = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_resource_collection_health_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceCollectionType = structure(logical(0), tags = list(location = "uri", locationName = "ResourceCollectionType", type = "string")), NextToken = structure(logical(0), tags = list(location = "querystring", locationName = "NextToken", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_resource_collection_health_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(CloudFormation = structure(list(structure(list(StackName = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer")), MeanTimeToRecoverInMilliseconds = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))), tags = list(type = "list")), Service = structure(list(structure(list(ServiceName = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValue = structure(logical(0), tags = list(type = "string")), Insight = structure(list(OpenProactiveInsights = structure(logical(0), tags = list(type = "integer")), OpenReactiveInsights = structure(logical(0), tags = list(type = "integer")), MeanTimeToRecoverInMilliseconds = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure")), AnalyzedResourceCount = structure(logical(0), tags = list(type = "long"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_service_integration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$describe_service_integration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ServiceIntegration = structure(list(OpsCenter = structure(list(OptInStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), LogsAnomalyDetection = structure(list(OptInStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), KMSServerSideEncryption = structure(list(KMSKeyId = structure(logical(0), tags = list(type = "string")), OptInStatus = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$get_cost_estimation_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(NextToken = structure(logical(0), tags = list(location = "querystring", locationName = "NextToken", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$get_cost_estimation_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), Status = structure(logical(0), tags = list(type = "string")), Costs = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), State = structure(logical(0), tags = list(type = "string")), Count = structure(logical(0), tags = list(type = "integer")), UnitCost = structure(logical(0), tags = list(type = "double")), Cost = structure(logical(0), tags = list(type = "double"))), tags = list(type = "structure"))), tags = list(type = "list")), TimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), TotalCost = structure(logical(0), tags = list(type = "double")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$get_resource_collection_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceCollectionType = structure(logical(0), tags = list(location = "uri", locationName = "ResourceCollectionType", type = "string")), NextToken = structure(logical(0), tags = list(location = "querystring", locationName = "NextToken", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$get_resource_collection_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_anomalies_for_insight_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightId = structure(logical(0), tags = list(location = "uri", locationName = "InsightId", type = "string")), StartTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string")), AccountId = structure(logical(0), tags = list(type = "string")), Filters = structure(list(ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_anomalies_for_insight_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveAnomalies = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), UpdateTime = structure(logical(0), tags = list(type = "timestamp")), AnomalyTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), AnomalyReportedTimeRange = structure(list(OpenTime = structure(logical(0), tags = list(type = "timestamp")), CloseTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), SourceDetails = structure(list(CloudWatchMetrics = structure(list(structure(list(MetricName = structure(logical(0), tags = list(type = "string")), Namespace = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Stat = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), Period = structure(logical(0), tags = list(type = "integer")), MetricDataSummary = structure(list(TimestampMetricValuePairList = structure(list(structure(list(Timestamp = structure(logical(0), tags = list(type = "timestamp")), MetricValue = structure(logical(0), tags = list(type = "double"))), tags = list(type = "structure"))), tags = list(type = "list")), StatusCode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), PerformanceInsightsMetrics = structure(list(structure(list(MetricDisplayName = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), ReferenceData = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), ComparisonValues = structure(list(ReferenceScalar = structure(list(Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure")), ReferenceMetric = structure(list(MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtAnomaly = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtBaseline = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedInsightId = structure(logical(0), tags = list(type = "string")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), Limit = structure(logical(0), tags = list(type = "double", box = TRUE)), SourceMetadata = structure(list(Source = structure(logical(0), tags = list(type = "string")), SourceResourceName = structure(logical(0), tags = list(type = "string")), SourceResourceType = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), AnomalyResources = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), ReactiveAnomalies = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), AnomalyTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), AnomalyReportedTimeRange = structure(list(OpenTime = structure(logical(0), tags = list(type = "timestamp")), CloseTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), SourceDetails = structure(list(CloudWatchMetrics = structure(list(structure(list(MetricName = structure(logical(0), tags = list(type = "string")), Namespace = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Stat = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), Period = structure(logical(0), tags = list(type = "integer")), MetricDataSummary = structure(list(TimestampMetricValuePairList = structure(list(structure(list(Timestamp = structure(logical(0), tags = list(type = "timestamp")), MetricValue = structure(logical(0), tags = list(type = "double"))), tags = list(type = "structure"))), tags = list(type = "list")), StatusCode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), PerformanceInsightsMetrics = structure(list(structure(list(MetricDisplayName = structure(logical(0), tags = list(type = "string")), Unit = structure(logical(0), tags = list(type = "string")), MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), ReferenceData = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), ComparisonValues = structure(list(ReferenceScalar = structure(list(Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure")), ReferenceMetric = structure(list(MetricQuery = structure(list(Metric = structure(logical(0), tags = list(type = "string")), GroupBy = structure(list(Group = structure(logical(0), tags = list(type = "string")), Dimensions = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Limit = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure")), Filter = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtAnomaly = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list")), StatsAtBaseline = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Value = structure(logical(0), tags = list(type = "double", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedInsightId = structure(logical(0), tags = list(type = "string")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), Type = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Description = structure(logical(0), tags = list(type = "string")), CausalAnomalyId = structure(logical(0), tags = list(type = "string")), AnomalyResources = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_anomalous_log_groups_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightId = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_anomalous_log_groups_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightId = structure(logical(0), tags = list(type = "string")), AnomalousLogGroups = structure(list(structure(list(LogGroupName = structure(logical(0), tags = list(type = "string")), ImpactStartTime = structure(logical(0), tags = list(type = "timestamp")), ImpactEndTime = structure(logical(0), tags = list(type = "timestamp")), NumberOfLogLinesScanned = structure(logical(0), tags = list(type = "integer")), LogAnomalyShowcases = structure(list(structure(list(LogAnomalyClasses = structure(list(structure(list(LogStreamName = structure(logical(0), tags = list(type = "string")), LogAnomalyType = structure(logical(0), tags = list(type = "string")), LogAnomalyToken = structure(logical(0), tags = list(type = "string")), LogEventId = structure(logical(0), tags = list(type = "string")), Explanation = structure(logical(0), tags = list(type = "string")), NumberOfLogLinesOccurrences = structure(logical(0), tags = list(type = "integer")), LogEventTimestamp = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_events_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Filters = structure(list(InsightId = structure(logical(0), tags = list(type = "string")), EventTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), EventClass = structure(logical(0), tags = list(type = "string")), EventSource = structure(logical(0), tags = list(type = "string")), DataSource = structure(logical(0), tags = list(type = "string")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string")), AccountId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_events_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Events = structure(list(structure(list(ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), Id = structure(logical(0), tags = list(type = "string")), Time = structure(logical(0), tags = list(type = "timestamp")), EventSource = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), DataSource = structure(logical(0), tags = list(type = "string")), EventClass = structure(logical(0), tags = list(type = "string")), Resources = structure(list(structure(list(Type = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Arn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_insights_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(StatusFilter = structure(list(Ongoing = structure(list(Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), Closed = structure(list(Type = structure(logical(0), tags = list(type = "string")), EndTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "structure")), Any = structure(list(Type = structure(logical(0), tags = list(type = "string")), StartTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_insights_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedResourceArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), ReactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedResourceArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_monitored_resources_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Filters = structure(list(ResourcePermission = structure(logical(0), tags = list(type = "string")), ResourceTypeFilters = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_monitored_resources_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(MonitoredResourceIdentifiers = structure(list(structure(list(MonitoredResourceName = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string")), ResourcePermission = structure(logical(0), tags = list(type = "string")), LastUpdated = structure(logical(0), tags = list(type = "timestamp")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_notification_channels_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_notification_channels_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Channels = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Config = structure(list(Sns = structure(list(TopicArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), Filters = structure(list(Severities = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), MessageTypes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_organization_insights_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(StatusFilter = structure(list(Ongoing = structure(list(Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), Closed = structure(list(Type = structure(logical(0), tags = list(type = "string")), EndTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "structure")), Any = structure(list(Type = structure(logical(0), tags = list(type = "string")), StartTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), AccountIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), OrganizationalUnitIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_organization_insights_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), AccountId = structure(logical(0), tags = list(type = "string")), OrganizationalUnitId = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), ReactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), AccountId = structure(logical(0), tags = list(type = "string")), OrganizationalUnitId = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_recommendations_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightId = structure(logical(0), tags = list(type = "string")), NextToken = structure(logical(0), tags = list(type = "string")), Locale = structure(logical(0), tags = list(type = "string")), AccountId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$list_recommendations_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Recommendations = structure(list(structure(list(Description = structure(logical(0), tags = list(type = "string")), Link = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Reason = structure(logical(0), tags = list(type = "string")), RelatedEvents = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Resources = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), RelatedAnomalies = structure(list(structure(list(Resources = structure(list(structure(list(Name = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), SourceDetails = structure(list(structure(list(CloudWatchMetrics = structure(list(structure(list(MetricName = structure(logical(0), tags = list(type = "string")), Namespace = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), AnomalyId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), Category = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$put_feedback_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(InsightFeedback = structure(list(Id = structure(logical(0), tags = list(type = "string")), Feedback = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$put_feedback_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$remove_notification_channel_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Id = structure(logical(0), tags = list(location = "uri", locationName = "Id", type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$remove_notification_channel_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$search_insights_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(StartTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), Filters = structure(list(Severities = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Statuses = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$search_insights_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedResourceArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), ReactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedResourceArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$search_organization_insights_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(AccountIds = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), StartTimeRange = structure(list(FromTime = structure(logical(0), tags = list(type = "timestamp")), ToTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), Filters = structure(list(Severities = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), Statuses = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure")), MaxResults = structure(logical(0), tags = list(type = "integer")), NextToken = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$search_organization_insights_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ProactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), PredictionTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedResourceArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), ReactiveInsights = structure(list(structure(list(Id = structure(logical(0), tags = list(type = "string")), Name = structure(logical(0), tags = list(type = "string")), Severity = structure(logical(0), tags = list(type = "string")), Status = structure(logical(0), tags = list(type = "string")), InsightTimeRange = structure(list(StartTime = structure(logical(0), tags = list(type = "timestamp")), EndTime = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ServiceCollection = structure(list(ServiceNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), AssociatedResourceArns = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$start_cost_estimation_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), ClientToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$start_cost_estimation_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$update_event_sources_config_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(EventSources = structure(list(AmazonCodeGuruProfiler = structure(list(Status = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$update_event_sources_config_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$update_resource_collection_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(Action = structure(logical(0), tags = list(type = "string")), ResourceCollection = structure(list(CloudFormation = structure(list(StackNames = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), Tags = structure(list(structure(list(AppBoundaryKey = structure(logical(0), tags = list(type = "string")), TagValues = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$update_resource_collection_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$update_service_integration_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ServiceIntegration = structure(list(OpsCenter = structure(list(OptInStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), LogsAnomalyDetection = structure(list(OptInStatus = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), KMSServerSideEncryption = structure(list(KMSKeyId = structure(logical(0), tags = list(type = "string")), OptInStatus = structure(logical(0), tags = list(type = "string")), Type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.devopsguru$update_service_integration_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}
