# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common populate
#' @include codepipeline_service.R
NULL

.codepipeline$acknowledge_job_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), nonce = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$acknowledge_job_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(status = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$acknowledge_third_party_job_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), nonce = structure(logical(0), tags = list(type = "string")), clientToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$acknowledge_third_party_job_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(status = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$create_custom_action_type_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(category = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string")), settings = structure(list(thirdPartyConfigurationUrl = structure(logical(0), tags = list(type = "string")), entityUrlTemplate = structure(logical(0), tags = list(type = "string")), executionUrlTemplate = structure(logical(0), tags = list(type = "string")), revisionUrlTemplate = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configurationProperties = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), required = structure(logical(0), tags = list(type = "boolean")), key = structure(logical(0), tags = list(type = "boolean")), secret = structure(logical(0), tags = list(type = "boolean")), queryable = structure(logical(0), tags = list(type = "boolean")), description = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), outputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$create_custom_action_type_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionType = structure(list(id = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), settings = structure(list(thirdPartyConfigurationUrl = structure(logical(0), tags = list(type = "string")), entityUrlTemplate = structure(logical(0), tags = list(type = "string")), executionUrlTemplate = structure(logical(0), tags = list(type = "string")), revisionUrlTemplate = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), actionConfigurationProperties = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), required = structure(logical(0), tags = list(type = "boolean")), key = structure(logical(0), tags = list(type = "boolean")), secret = structure(logical(0), tags = list(type = "boolean")), queryable = structure(logical(0), tags = list(type = "boolean")), description = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), outputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))), tags = list(type = "structure")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$create_pipeline_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipeline = structure(list(name = structure(logical(0), tags = list(type = "string")), roleArn = structure(logical(0), tags = list(type = "string")), artifactStore = structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), artifactStores = structure(list(structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "map")), stages = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), blockers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), actions = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), runOrder = structure(logical(0), tags = list(type = "integer")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), files = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), namespace = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE)), environmentVariables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), onFailure = structure(list(result = structure(logical(0), tags = list(type = "string")), retryConfiguration = structure(list(retryMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onSuccess = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), beforeEntry = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), version = structure(logical(0), tags = list(type = "integer")), executionMode = structure(logical(0), tags = list(type = "string")), pipelineType = structure(logical(0), tags = list(type = "string")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), defaultValue = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), triggers = structure(list(structure(list(providerType = structure(logical(0), tags = list(type = "string")), gitConfiguration = structure(list(sourceActionName = structure(logical(0), tags = list(type = "string")), push = structure(list(structure(list(tags = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), pullRequest = structure(list(structure(list(events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$create_pipeline_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipeline = structure(list(name = structure(logical(0), tags = list(type = "string")), roleArn = structure(logical(0), tags = list(type = "string")), artifactStore = structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), artifactStores = structure(list(structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "map")), stages = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), blockers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), actions = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), runOrder = structure(logical(0), tags = list(type = "integer")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), files = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), namespace = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE)), environmentVariables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), onFailure = structure(list(result = structure(logical(0), tags = list(type = "string")), retryConfiguration = structure(list(retryMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onSuccess = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), beforeEntry = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), version = structure(logical(0), tags = list(type = "integer")), executionMode = structure(logical(0), tags = list(type = "string")), pipelineType = structure(logical(0), tags = list(type = "string")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), defaultValue = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), triggers = structure(list(structure(list(providerType = structure(logical(0), tags = list(type = "string")), gitConfiguration = structure(list(sourceActionName = structure(logical(0), tags = list(type = "string")), push = structure(list(structure(list(tags = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), pullRequest = structure(list(structure(list(events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$delete_custom_action_type_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(category = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$delete_custom_action_type_output <- function(...) {
  list()
}

.codepipeline$delete_pipeline_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$delete_pipeline_output <- function(...) {
  list()
}

.codepipeline$delete_webhook_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$delete_webhook_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$deregister_webhook_with_third_party_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(webhookName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$deregister_webhook_with_third_party_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$disable_stage_transition_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), transitionType = structure(logical(0), tags = list(type = "string")), reason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$disable_stage_transition_output <- function(...) {
  list()
}

.codepipeline$enable_stage_transition_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), transitionType = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$enable_stage_transition_output <- function(...) {
  list()
}

.codepipeline$get_action_type_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_action_type_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionType = structure(list(description = structure(logical(0), tags = list(type = "string")), executor = structure(list(configuration = structure(list(lambdaExecutorConfiguration = structure(list(lambdaFunctionArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), jobWorkerExecutorConfiguration = structure(list(pollingAccounts = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), pollingServicePrincipals = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure")), type = structure(logical(0), tags = list(type = "string")), policyStatementsTemplate = structure(logical(0), tags = list(type = "string")), jobTimeout = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), id = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), inputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), outputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), permissions = structure(list(allowedAccounts = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), properties = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), optional = structure(logical(0), tags = list(type = "boolean")), key = structure(logical(0), tags = list(type = "boolean")), noEcho = structure(logical(0), tags = list(type = "boolean")), queryable = structure(logical(0), tags = list(type = "boolean")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), urls = structure(list(configurationUrl = structure(logical(0), tags = list(type = "string")), entityUrlTemplate = structure(logical(0), tags = list(type = "string")), executionUrlTemplate = structure(logical(0), tags = list(type = "string")), revisionUrlTemplate = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_job_details_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_job_details_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobDetails = structure(list(id = structure(logical(0), tags = list(type = "string")), data = structure(list(actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), actionConfiguration = structure(list(configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), pipelineContext = structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stage = structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), action = structure(list(name = structure(logical(0), tags = list(type = "string")), actionExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), pipelineArn = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revision = structure(logical(0), tags = list(type = "string")), location = structure(list(type = structure(logical(0), tags = list(type = "string")), s3Location = structure(list(bucketName = structure(logical(0), tags = list(type = "string")), objectKey = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revision = structure(logical(0), tags = list(type = "string")), location = structure(list(type = structure(logical(0), tags = list(type = "string")), s3Location = structure(list(bucketName = structure(logical(0), tags = list(type = "string")), objectKey = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), artifactCredentials = structure(list(accessKeyId = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), secretAccessKey = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), sessionToken = structure(logical(0), tags = list(type = "string", sensitive = TRUE))), tags = list(type = "structure", sensitive = TRUE)), continuationToken = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), accountId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_pipeline_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(name = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_pipeline_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipeline = structure(list(name = structure(logical(0), tags = list(type = "string")), roleArn = structure(logical(0), tags = list(type = "string")), artifactStore = structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), artifactStores = structure(list(structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "map")), stages = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), blockers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), actions = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), runOrder = structure(logical(0), tags = list(type = "integer")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), files = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), namespace = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE)), environmentVariables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), onFailure = structure(list(result = structure(logical(0), tags = list(type = "string")), retryConfiguration = structure(list(retryMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onSuccess = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), beforeEntry = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), version = structure(logical(0), tags = list(type = "integer")), executionMode = structure(logical(0), tags = list(type = "string")), pipelineType = structure(logical(0), tags = list(type = "string")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), defaultValue = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), triggers = structure(list(structure(list(providerType = structure(logical(0), tags = list(type = "string")), gitConfiguration = structure(list(sourceActionName = structure(logical(0), tags = list(type = "string")), push = structure(list(structure(list(tags = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), pullRequest = structure(list(structure(list(events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), metadata = structure(list(pipelineArn = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp")), updated = structure(logical(0), tags = list(type = "timestamp")), pollingDisabledAt = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_pipeline_execution_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_pipeline_execution_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineExecution = structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), pipelineVersion = structure(logical(0), tags = list(type = "integer")), pipelineExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), statusSummary = structure(logical(0), tags = list(type = "string")), artifactRevisions = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), revisionChangeIdentifier = structure(logical(0), tags = list(type = "string")), revisionSummary = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp")), revisionUrl = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), resolvedValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), trigger = structure(list(triggerType = structure(logical(0), tags = list(type = "string")), triggerDetail = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), executionMode = structure(logical(0), tags = list(type = "string")), executionType = structure(logical(0), tags = list(type = "string")), rollbackMetadata = structure(list(rollbackTargetPipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_pipeline_state_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_pipeline_state_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), pipelineVersion = structure(logical(0), tags = list(type = "integer")), stageStates = structure(list(structure(list(stageName = structure(logical(0), tags = list(type = "string")), inboundExecution = structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), inboundExecutions = structure(list(structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), inboundTransitionState = structure(list(enabled = structure(logical(0), tags = list(type = "boolean")), lastChangedBy = structure(logical(0), tags = list(type = "string")), lastChangedAt = structure(logical(0), tags = list(type = "timestamp")), disabledReason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), actionStates = structure(list(structure(list(actionName = structure(logical(0), tags = list(type = "string")), currentRevision = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), revisionChangeId = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), latestExecution = structure(list(actionExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp")), token = structure(logical(0), tags = list(type = "string")), lastUpdatedBy = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string")), externalExecutionUrl = structure(logical(0), tags = list(type = "string")), percentComplete = structure(logical(0), tags = list(type = "integer")), errorDetails = structure(list(code = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), logStreamARN = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), entityUrl = structure(logical(0), tags = list(type = "string")), revisionUrl = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), latestExecution = structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), beforeEntryConditionState = structure(list(latestExecution = structure(list(status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditionStates = structure(list(structure(list(latestExecution = structure(list(status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ruleStates = structure(list(structure(list(ruleName = structure(logical(0), tags = list(type = "string")), currentRevision = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), revisionChangeId = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), latestExecution = structure(list(ruleExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp")), token = structure(logical(0), tags = list(type = "string")), lastUpdatedBy = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string")), externalExecutionUrl = structure(logical(0), tags = list(type = "string")), errorDetails = structure(list(code = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), entityUrl = structure(logical(0), tags = list(type = "string")), revisionUrl = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onSuccessConditionState = structure(list(latestExecution = structure(list(status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditionStates = structure(list(structure(list(latestExecution = structure(list(status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ruleStates = structure(list(structure(list(ruleName = structure(logical(0), tags = list(type = "string")), currentRevision = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), revisionChangeId = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), latestExecution = structure(list(ruleExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp")), token = structure(logical(0), tags = list(type = "string")), lastUpdatedBy = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string")), externalExecutionUrl = structure(logical(0), tags = list(type = "string")), errorDetails = structure(list(code = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), entityUrl = structure(logical(0), tags = list(type = "string")), revisionUrl = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onFailureConditionState = structure(list(latestExecution = structure(list(status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditionStates = structure(list(structure(list(latestExecution = structure(list(status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), ruleStates = structure(list(structure(list(ruleName = structure(logical(0), tags = list(type = "string")), currentRevision = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), revisionChangeId = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure")), latestExecution = structure(list(ruleExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), summary = structure(logical(0), tags = list(type = "string")), lastStatusChange = structure(logical(0), tags = list(type = "timestamp")), token = structure(logical(0), tags = list(type = "string")), lastUpdatedBy = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string")), externalExecutionUrl = structure(logical(0), tags = list(type = "string")), errorDetails = structure(list(code = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), entityUrl = structure(logical(0), tags = list(type = "string")), revisionUrl = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), retryStageMetadata = structure(list(autoStageRetryAttempt = structure(logical(0), tags = list(type = "integer")), manualStageRetryAttempt = structure(logical(0), tags = list(type = "integer")), latestRetryTrigger = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), created = structure(logical(0), tags = list(type = "timestamp")), updated = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_third_party_job_details_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), clientToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$get_third_party_job_details_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobDetails = structure(list(id = structure(logical(0), tags = list(type = "string")), data = structure(list(actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), actionConfiguration = structure(list(configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), pipelineContext = structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stage = structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), action = structure(list(name = structure(logical(0), tags = list(type = "string")), actionExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), pipelineArn = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revision = structure(logical(0), tags = list(type = "string")), location = structure(list(type = structure(logical(0), tags = list(type = "string")), s3Location = structure(list(bucketName = structure(logical(0), tags = list(type = "string")), objectKey = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revision = structure(logical(0), tags = list(type = "string")), location = structure(list(type = structure(logical(0), tags = list(type = "string")), s3Location = structure(list(bucketName = structure(logical(0), tags = list(type = "string")), objectKey = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), artifactCredentials = structure(list(accessKeyId = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), secretAccessKey = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), sessionToken = structure(logical(0), tags = list(type = "string", sensitive = TRUE))), tags = list(type = "structure", sensitive = TRUE)), continuationToken = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), nonce = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_action_executions_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), filter = structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), latestInPipelineExecution = structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), startTimeRange = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), maxResults = structure(logical(0), tags = list(type = "integer")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_action_executions_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionExecutionDetails = structure(list(structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), actionExecutionId = structure(logical(0), tags = list(type = "string")), pipelineVersion = structure(logical(0), tags = list(type = "integer")), stageName = structure(logical(0), tags = list(type = "string")), actionName = structure(logical(0), tags = list(type = "string")), startTime = structure(logical(0), tags = list(type = "timestamp")), lastUpdateTime = structure(logical(0), tags = list(type = "timestamp")), updatedBy = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), input = structure(list(actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), resolvedConfiguration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), s3location = structure(list(bucket = structure(logical(0), tags = list(type = "string")), key = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), namespace = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), output = structure(list(outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), s3location = structure(list(bucket = structure(logical(0), tags = list(type = "string")), key = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), executionResult = structure(list(externalExecutionId = structure(logical(0), tags = list(type = "string")), externalExecutionSummary = structure(logical(0), tags = list(type = "string")), externalExecutionUrl = structure(logical(0), tags = list(type = "string")), errorDetails = structure(list(code = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), logStreamARN = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_action_types_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionOwnerFilter = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), regionFilter = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_action_types_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionTypes = structure(list(structure(list(id = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), settings = structure(list(thirdPartyConfigurationUrl = structure(logical(0), tags = list(type = "string")), entityUrlTemplate = structure(logical(0), tags = list(type = "string")), executionUrlTemplate = structure(logical(0), tags = list(type = "string")), revisionUrlTemplate = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), actionConfigurationProperties = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), required = structure(logical(0), tags = list(type = "boolean")), key = structure(logical(0), tags = list(type = "boolean")), secret = structure(logical(0), tags = list(type = "boolean")), queryable = structure(logical(0), tags = list(type = "boolean")), description = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), outputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_deploy_action_execution_targets_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), actionExecutionId = structure(logical(0), tags = list(type = "string")), filters = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), values = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), maxResults = structure(logical(0), tags = list(type = "integer")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_deploy_action_execution_targets_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(targets = structure(list(structure(list(targetId = structure(logical(0), tags = list(type = "string")), targetType = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), startTime = structure(logical(0), tags = list(type = "timestamp")), endTime = structure(logical(0), tags = list(type = "timestamp")), events = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), startTime = structure(logical(0), tags = list(type = "timestamp")), endTime = structure(logical(0), tags = list(type = "timestamp")), context = structure(list(ssmCommandId = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_pipeline_executions_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer")), filter = structure(list(succeededInStage = structure(list(stageName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_pipeline_executions_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineExecutionSummaries = structure(list(structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), statusSummary = structure(logical(0), tags = list(type = "string")), startTime = structure(logical(0), tags = list(type = "timestamp")), lastUpdateTime = structure(logical(0), tags = list(type = "timestamp")), sourceRevisions = structure(list(structure(list(actionName = structure(logical(0), tags = list(type = "string")), revisionId = structure(logical(0), tags = list(type = "string")), revisionSummary = structure(logical(0), tags = list(type = "string")), revisionUrl = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), trigger = structure(list(triggerType = structure(logical(0), tags = list(type = "string")), triggerDetail = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), stopTrigger = structure(list(reason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), executionMode = structure(logical(0), tags = list(type = "string")), executionType = structure(logical(0), tags = list(type = "string")), rollbackMetadata = structure(list(rollbackTargetPipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_pipelines_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_pipelines_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelines = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "integer")), pipelineType = structure(logical(0), tags = list(type = "string")), executionMode = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp")), updated = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_rule_executions_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), filter = structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), latestInPipelineExecution = structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), startTimeRange = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), maxResults = structure(logical(0), tags = list(type = "integer")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_rule_executions_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ruleExecutionDetails = structure(list(structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string")), ruleExecutionId = structure(logical(0), tags = list(type = "string")), pipelineVersion = structure(logical(0), tags = list(type = "integer")), stageName = structure(logical(0), tags = list(type = "string")), ruleName = structure(logical(0), tags = list(type = "string")), startTime = structure(logical(0), tags = list(type = "timestamp")), lastUpdateTime = structure(logical(0), tags = list(type = "timestamp")), updatedBy = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string")), input = structure(list(ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), resolvedConfiguration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), s3location = structure(list(bucket = structure(logical(0), tags = list(type = "string")), key = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), output = structure(list(executionResult = structure(list(externalExecutionId = structure(logical(0), tags = list(type = "string")), externalExecutionSummary = structure(logical(0), tags = list(type = "string")), externalExecutionUrl = structure(logical(0), tags = list(type = "string")), errorDetails = structure(list(code = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_rule_types_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ruleOwnerFilter = structure(logical(0), tags = list(type = "string")), regionFilter = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_rule_types_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(ruleTypes = structure(list(structure(list(id = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), settings = structure(list(thirdPartyConfigurationUrl = structure(logical(0), tags = list(type = "string")), entityUrlTemplate = structure(logical(0), tags = list(type = "string")), executionUrlTemplate = structure(logical(0), tags = list(type = "string")), revisionUrlTemplate = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), ruleConfigurationProperties = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), required = structure(logical(0), tags = list(type = "boolean")), key = structure(logical(0), tags = list(type = "boolean")), secret = structure(logical(0), tags = list(type = "boolean")), queryable = structure(logical(0), tags = list(type = "boolean")), description = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_tags_for_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(resourceArn = structure(logical(0), tags = list(type = "string")), nextToken = structure(logical(0), tags = list(type = "string")), maxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_tags_for_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), nextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_webhooks_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(NextToken = structure(logical(0), tags = list(type = "string")), MaxResults = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$list_webhooks_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(webhooks = structure(list(structure(list(definition = structure(list(name = structure(logical(0), tags = list(type = "string")), targetPipeline = structure(logical(0), tags = list(type = "string")), targetAction = structure(logical(0), tags = list(type = "string")), filters = structure(list(structure(list(jsonPath = structure(logical(0), tags = list(type = "string")), matchEquals = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), authentication = structure(logical(0), tags = list(type = "string")), authenticationConfiguration = structure(list(AllowedIPRange = structure(logical(0), tags = list(type = "string")), SecretToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), url = structure(logical(0), tags = list(type = "string")), errorMessage = structure(logical(0), tags = list(type = "string")), errorCode = structure(logical(0), tags = list(type = "string")), lastTriggered = structure(logical(0), tags = list(type = "timestamp")), arn = structure(logical(0), tags = list(type = "string")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), NextToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$override_stage_condition_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string")), conditionType = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$override_stage_condition_output <- function(...) {
  list()
}

.codepipeline$poll_for_jobs_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), maxBatchSize = structure(logical(0), tags = list(type = "integer")), queryParam = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$poll_for_jobs_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobs = structure(list(structure(list(id = structure(logical(0), tags = list(type = "string")), data = structure(list(actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), actionConfiguration = structure(list(configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure")), pipelineContext = structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stage = structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), action = structure(list(name = structure(logical(0), tags = list(type = "string")), actionExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), pipelineArn = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revision = structure(logical(0), tags = list(type = "string")), location = structure(list(type = structure(logical(0), tags = list(type = "string")), s3Location = structure(list(bucketName = structure(logical(0), tags = list(type = "string")), objectKey = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), revision = structure(logical(0), tags = list(type = "string")), location = structure(list(type = structure(logical(0), tags = list(type = "string")), s3Location = structure(list(bucketName = structure(logical(0), tags = list(type = "string")), objectKey = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), artifactCredentials = structure(list(accessKeyId = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), secretAccessKey = structure(logical(0), tags = list(type = "string", sensitive = TRUE)), sessionToken = structure(logical(0), tags = list(type = "string", sensitive = TRUE))), tags = list(type = "structure", sensitive = TRUE)), continuationToken = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), nonce = structure(logical(0), tags = list(type = "string")), accountId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$poll_for_third_party_jobs_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), maxBatchSize = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$poll_for_third_party_jobs_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobs = structure(list(structure(list(clientId = structure(logical(0), tags = list(type = "string")), jobId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_action_revision_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), actionName = structure(logical(0), tags = list(type = "string")), actionRevision = structure(list(revisionId = structure(logical(0), tags = list(type = "string")), revisionChangeId = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_action_revision_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(newRevision = structure(logical(0), tags = list(type = "boolean")), pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_approval_result_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), actionName = structure(logical(0), tags = list(type = "string")), result = structure(list(summary = structure(logical(0), tags = list(type = "string")), status = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), token = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_approval_result_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(approvedAt = structure(logical(0), tags = list(type = "timestamp"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_job_failure_result_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), failureDetails = structure(list(type = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_job_failure_result_output <- function(...) {
  list()
}

.codepipeline$put_job_success_result_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), currentRevision = structure(list(revision = structure(logical(0), tags = list(type = "string")), changeIdentifier = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp")), revisionSummary = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), continuationToken = structure(logical(0), tags = list(type = "string")), executionDetails = structure(list(summary = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string")), percentComplete = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_job_success_result_output <- function(...) {
  list()
}

.codepipeline$put_third_party_job_failure_result_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), clientToken = structure(logical(0), tags = list(type = "string")), failureDetails = structure(list(type = structure(logical(0), tags = list(type = "string")), message = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_third_party_job_failure_result_output <- function(...) {
  list()
}

.codepipeline$put_third_party_job_success_result_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(jobId = structure(logical(0), tags = list(type = "string")), clientToken = structure(logical(0), tags = list(type = "string")), currentRevision = structure(list(revision = structure(logical(0), tags = list(type = "string")), changeIdentifier = structure(logical(0), tags = list(type = "string")), created = structure(logical(0), tags = list(type = "timestamp")), revisionSummary = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), continuationToken = structure(logical(0), tags = list(type = "string")), executionDetails = structure(list(summary = structure(logical(0), tags = list(type = "string")), externalExecutionId = structure(logical(0), tags = list(type = "string")), percentComplete = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_third_party_job_success_result_output <- function(...) {
  list()
}

.codepipeline$put_webhook_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(webhook = structure(list(name = structure(logical(0), tags = list(type = "string")), targetPipeline = structure(logical(0), tags = list(type = "string")), targetAction = structure(logical(0), tags = list(type = "string")), filters = structure(list(structure(list(jsonPath = structure(logical(0), tags = list(type = "string")), matchEquals = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), authentication = structure(logical(0), tags = list(type = "string")), authenticationConfiguration = structure(list(AllowedIPRange = structure(logical(0), tags = list(type = "string")), SecretToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$put_webhook_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(webhook = structure(list(definition = structure(list(name = structure(logical(0), tags = list(type = "string")), targetPipeline = structure(logical(0), tags = list(type = "string")), targetAction = structure(logical(0), tags = list(type = "string")), filters = structure(list(structure(list(jsonPath = structure(logical(0), tags = list(type = "string")), matchEquals = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), authentication = structure(logical(0), tags = list(type = "string")), authenticationConfiguration = structure(list(AllowedIPRange = structure(logical(0), tags = list(type = "string")), SecretToken = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), url = structure(logical(0), tags = list(type = "string")), errorMessage = structure(logical(0), tags = list(type = "string")), errorCode = structure(logical(0), tags = list(type = "string")), lastTriggered = structure(logical(0), tags = list(type = "timestamp")), arn = structure(logical(0), tags = list(type = "string")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$register_webhook_with_third_party_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(webhookName = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$register_webhook_with_third_party_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$retry_stage_execution_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string")), retryMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$retry_stage_execution_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$rollback_stage_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), stageName = structure(logical(0), tags = list(type = "string")), targetPipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$rollback_stage_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$start_pipeline_execution_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(name = structure(logical(0), tags = list(type = "string")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), clientRequestToken = structure(logical(0), tags = list(idempotencyToken = TRUE, type = "string")), sourceRevisions = structure(list(structure(list(actionName = structure(logical(0), tags = list(type = "string")), revisionType = structure(logical(0), tags = list(type = "string")), revisionValue = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$start_pipeline_execution_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$stop_pipeline_execution_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineName = structure(logical(0), tags = list(type = "string")), pipelineExecutionId = structure(logical(0), tags = list(type = "string")), abandon = structure(logical(0), tags = list(type = "boolean")), reason = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$stop_pipeline_execution_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipelineExecutionId = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$tag_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(resourceArn = structure(logical(0), tags = list(type = "string")), tags = structure(list(structure(list(key = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$tag_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$untag_resource_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(resourceArn = structure(logical(0), tags = list(type = "string")), tagKeys = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$untag_resource_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$update_action_type_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(actionType = structure(list(description = structure(logical(0), tags = list(type = "string")), executor = structure(list(configuration = structure(list(lambdaExecutorConfiguration = structure(list(lambdaFunctionArn = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), jobWorkerExecutorConfiguration = structure(list(pollingAccounts = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), pollingServicePrincipals = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure")), type = structure(logical(0), tags = list(type = "string")), policyStatementsTemplate = structure(logical(0), tags = list(type = "string")), jobTimeout = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), id = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), inputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), outputArtifactDetails = structure(list(minimumCount = structure(logical(0), tags = list(type = "integer")), maximumCount = structure(logical(0), tags = list(type = "integer"))), tags = list(type = "structure")), permissions = structure(list(allowedAccounts = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), properties = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), optional = structure(logical(0), tags = list(type = "boolean")), key = structure(logical(0), tags = list(type = "boolean")), noEcho = structure(logical(0), tags = list(type = "boolean")), queryable = structure(logical(0), tags = list(type = "boolean")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), urls = structure(list(configurationUrl = structure(logical(0), tags = list(type = "string")), entityUrlTemplate = structure(logical(0), tags = list(type = "string")), executionUrlTemplate = structure(logical(0), tags = list(type = "string")), revisionUrlTemplate = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$update_action_type_output <- function(...) {
  list()
}

.codepipeline$update_pipeline_input <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipeline = structure(list(name = structure(logical(0), tags = list(type = "string")), roleArn = structure(logical(0), tags = list(type = "string")), artifactStore = structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), artifactStores = structure(list(structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "map")), stages = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), blockers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), actions = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), runOrder = structure(logical(0), tags = list(type = "integer")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), files = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), namespace = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE)), environmentVariables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), onFailure = structure(list(result = structure(logical(0), tags = list(type = "string")), retryConfiguration = structure(list(retryMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onSuccess = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), beforeEntry = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), version = structure(logical(0), tags = list(type = "integer")), executionMode = structure(logical(0), tags = list(type = "string")), pipelineType = structure(logical(0), tags = list(type = "string")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), defaultValue = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), triggers = structure(list(structure(list(providerType = structure(logical(0), tags = list(type = "string")), gitConfiguration = structure(list(sourceActionName = structure(logical(0), tags = list(type = "string")), push = structure(list(structure(list(tags = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), pullRequest = structure(list(structure(list(events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}

.codepipeline$update_pipeline_output <- function(...) {
  args <- c(as.list(environment()), list(...))
  shape <- structure(list(pipeline = structure(list(name = structure(logical(0), tags = list(type = "string")), roleArn = structure(logical(0), tags = list(type = "string")), artifactStore = structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure")), artifactStores = structure(list(structure(list(type = structure(logical(0), tags = list(type = "string")), location = structure(logical(0), tags = list(type = "string")), encryptionKey = structure(list(id = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "map")), stages = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), blockers = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), actions = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), actionTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), runOrder = structure(logical(0), tags = list(type = "integer")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), outputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), files = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), outputVariables = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), namespace = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE)), environmentVariables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), value = structure(logical(0), tags = list(type = "string")), type = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list")), onFailure = structure(list(result = structure(logical(0), tags = list(type = "string")), retryConfiguration = structure(list(retryMode = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), onSuccess = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure")), beforeEntry = structure(list(conditions = structure(list(structure(list(result = structure(logical(0), tags = list(type = "string")), rules = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), ruleTypeId = structure(list(category = structure(logical(0), tags = list(type = "string")), owner = structure(logical(0), tags = list(type = "string")), provider = structure(logical(0), tags = list(type = "string")), version = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure")), configuration = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "map")), commands = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), inputArtifacts = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), roleArn = structure(logical(0), tags = list(type = "string")), region = structure(logical(0), tags = list(type = "string")), timeoutInMinutes = structure(logical(0), tags = list(type = "integer", box = TRUE))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), version = structure(logical(0), tags = list(type = "integer")), executionMode = structure(logical(0), tags = list(type = "string")), pipelineType = structure(logical(0), tags = list(type = "string")), variables = structure(list(structure(list(name = structure(logical(0), tags = list(type = "string")), defaultValue = structure(logical(0), tags = list(type = "string")), description = structure(logical(0), tags = list(type = "string"))), tags = list(type = "structure"))), tags = list(type = "list")), triggers = structure(list(structure(list(providerType = structure(logical(0), tags = list(type = "string")), gitConfiguration = structure(list(sourceActionName = structure(logical(0), tags = list(type = "string")), push = structure(list(structure(list(tags = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list")), pullRequest = structure(list(structure(list(events = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), branches = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure")), filePaths = structure(list(includes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list")), excludes = structure(list(structure(logical(0), tags = list(type = "string"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))), tags = list(type = "list"))), tags = list(type = "structure"))), tags = list(type = "structure"))
  return(populate(args, shape))
}
