% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wellarchitected_operations.R
\name{wellarchitected_list_notifications}
\alias{wellarchitected_list_notifications}
\title{List lens notifications}
\usage{
wellarchitected_list_notifications(
  WorkloadId = NULL,
  NextToken = NULL,
  MaxResults = NULL,
  ResourceArn = NULL
)
}
\arguments{
\item{WorkloadId}{The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.}

\item{NextToken}{The token to use to retrieve the next set of results.}

\item{MaxResults}{The maximum number of results to return for this request.}

\item{ResourceArn}{The ARN for the related resource for the notification.

Only one of \code{WorkloadID} or \code{ResourceARN} should be specified.}
}
\description{
List lens notifications.

See \url{https://www.paws-r-sdk.com/docs/wellarchitected_list_notifications/} for full documentation.
}
\keyword{internal}
