% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/xray_operations.R
\name{xray_get_insight_events}
\alias{xray_get_insight_events}
\title{X-Ray reevaluates insights periodically until they're resolved, and
records each intermediate state as an event}
\usage{
xray_get_insight_events(InsightId, MaxResults = NULL, NextToken = NULL)
}
\arguments{
\item{InsightId}{[required] The insight's unique identifier. Use the GetInsightSummaries action to retrieve an InsightId.}

\item{MaxResults}{Used to retrieve at most the specified value of events.}

\item{NextToken}{Specify the pagination token returned by a previous request to retrieve the next page of events.}
}
\description{
X-Ray reevaluates insights periodically until they're resolved, and records each intermediate state as an event. You can review an insight's events in the Impact Timeline on the Inspect page in the X-Ray console.

See \url{https://www.paws-r-sdk.com/docs/xray_get_insight_events/} for full documentation.
}
\keyword{internal}
