% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/codeconnections_operations.R
\name{codeconnections_get_connection}
\alias{codeconnections_get_connection}
\title{Returns the connection ARN and details such as status, owner, and
provider type}
\usage{
codeconnections_get_connection(ConnectionArn)
}
\arguments{
\item{ConnectionArn}{[required] The Amazon Resource Name (ARN) of a connection.}
}
\description{
Returns the connection ARN and details such as status, owner, and provider type.

See \url{https://www.paws-r-sdk.com/docs/codeconnections_get_connection/} for full documentation.
}
\keyword{internal}
