% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/codecommit_operations.R
\name{codecommit_list_repositories}
\alias{codecommit_list_repositories}
\title{Gets information about one or more repositories}
\usage{
codecommit_list_repositories(nextToken = NULL, sortBy = NULL, order = NULL)
}
\arguments{
\item{nextToken}{An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to CodeCommit, another page of 1,000 records is retrieved.}

\item{sortBy}{The criteria used to sort the results of a list repositories operation.}

\item{order}{The order in which to sort the results of a list repositories operation.}
}
\description{
Gets information about one or more repositories.

See \url{https://www.paws-r-sdk.com/docs/codecommit_list_repositories/} for full documentation.
}
\keyword{internal}
