% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wellarchitected_operations.R
\name{wellarchitected_tag_resource}
\alias{wellarchitected_tag_resource}
\title{Adds one or more tags to the specified resource}
\usage{
wellarchitected_tag_resource(WorkloadArn, Tags)
}
\arguments{
\item{WorkloadArn}{[required] The ARN for the workload.}

\item{Tags}{[required] The tags for the resource.}
}
\description{
Adds one or more tags to the specified resource.

See \url{https://www.paws-r-sdk.com/docs/wellarchitected_tag_resource/} for full documentation.
}
\keyword{internal}
