% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/drs_operations.R
\name{drs_put_launch_action}
\alias{drs_put_launch_action}
\title{Puts a resource launch action}
\usage{
drs_put_launch_action(
  resourceId,
  actionCode,
  order,
  actionId,
  optional,
  active,
  name,
  actionVersion,
  category,
  parameters = NULL,
  description
)
}
\arguments{
\item{resourceId}{[required] Launch configuration template Id or Source Server Id}

\item{actionCode}{[required] Launch action code.}

\item{order}{[required] Launch action order.}

\item{actionId}{[required] Launch action Id.}

\item{optional}{[required] Whether the launch will not be marked as failed if this action fails.}

\item{active}{[required] Whether the launch action is active.}

\item{name}{[required] Launch action name.}

\item{actionVersion}{[required] Launch action version.}

\item{category}{[required] Launch action category.}

\item{parameters}{Launch action parameters.}

\item{description}{[required] Launch action description.}
}
\description{
Puts a resource launch action.

See \url{https://www.paws-r-sdk.com/docs/drs_put_launch_action/} for full documentation.
}
\keyword{internal}
