% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/drs_operations.R
\name{drs_list_launch_actions}
\alias{drs_list_launch_actions}
\title{Lists resource launch actions}
\usage{
drs_list_launch_actions(
  resourceId,
  filters = NULL,
  maxResults = NULL,
  nextToken = NULL
)
}
\arguments{
\item{resourceId}{[required] Launch configuration template Id or Source Server Id}

\item{filters}{Filters to apply when listing resource launch actions.}

\item{maxResults}{Maximum amount of items to return when listing resource launch actions.}

\item{nextToken}{Next token to use when listing resource launch actions.}
}
\description{
Lists resource launch actions.

See \url{https://www.paws-r-sdk.com/docs/drs_list_launch_actions/} for full documentation.
}
\keyword{internal}
