% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wellarchitected_operations.R
\name{wellarchitected_list_share_invitations}
\alias{wellarchitected_list_share_invitations}
\title{List the share invitations}
\usage{
wellarchitected_list_share_invitations(
  WorkloadNamePrefix = NULL,
  LensNamePrefix = NULL,
  ShareResourceType = NULL,
  NextToken = NULL,
  MaxResults = NULL,
  ProfileNamePrefix = NULL,
  TemplateNamePrefix = NULL
)
}
\arguments{
\item{WorkloadNamePrefix}{An optional string added to the beginning of each workload name returned in the results.}

\item{LensNamePrefix}{An optional string added to the beginning of each lens name returned in the results.}

\item{ShareResourceType}{The type of share invitations to be returned.}

\item{NextToken}{The token to use to retrieve the next set of results.}

\item{MaxResults}{The maximum number of results to return for this request.}

\item{ProfileNamePrefix}{An optional string added to the beginning of each profile name returned in the results.}

\item{TemplateNamePrefix}{An optional string added to the beginning of each review template name returned in the results.}
}
\description{
List the share invitations.

See \url{https://www.paws-r-sdk.com/docs/wellarchitected_list_share_invitations/} for full documentation.
}
\keyword{internal}
