% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/drs_operations.R
\name{drs_update_launch_configuration_template}
\alias{drs_update_launch_configuration_template}
\title{Updates an existing Launch Configuration Template by ID}
\usage{
drs_update_launch_configuration_template(
  launchConfigurationTemplateID,
  launchDisposition = NULL,
  targetInstanceTypeRightSizingMethod = NULL,
  copyPrivateIp = NULL,
  copyTags = NULL,
  licensing = NULL,
  exportBucketArn = NULL,
  postLaunchEnabled = NULL,
  launchIntoSourceInstance = NULL
)
}
\arguments{
\item{launchConfigurationTemplateID}{[required] Launch Configuration Template ID.}

\item{launchDisposition}{Launch disposition.}

\item{targetInstanceTypeRightSizingMethod}{Target instance type right-sizing method.}

\item{copyPrivateIp}{Copy private IP.}

\item{copyTags}{Copy tags.}

\item{licensing}{Licensing.}

\item{exportBucketArn}{S3 bucket ARN to export Source Network templates.}

\item{postLaunchEnabled}{Whether we want to activate post-launch actions.}

\item{launchIntoSourceInstance}{DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.}
}
\description{
Updates an existing Launch Configuration Template by ID.

See \url{https://www.paws-r-sdk.com/docs/drs_update_launch_configuration_template/} for full documentation.
}
\keyword{internal}
