% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/codecommit_operations.R
\name{codecommit_batch_associate_approval_rule_template_with_repositories}
\alias{codecommit_batch_associate_approval_rule_template_with_repositories}
\title{Creates an association between an approval rule template and one or more
specified repositories}
\usage{
codecommit_batch_associate_approval_rule_template_with_repositories(
  approvalRuleTemplateName,
  repositoryNames
)
}
\arguments{
\item{approvalRuleTemplateName}{[required] The name of the template you want to associate with one or more repositories.}

\item{repositoryNames}{[required] The names of the repositories you want to associate with the template.

The length constraint limit is for each string in the array. The array itself can be empty.}
}
\description{
Creates an association between an approval rule template and one or more specified repositories.

See \url{https://www.paws-r-sdk.com/docs/codecommit_batch_associate_approval_rule_template_with_repositories/} for full documentation.
}
\keyword{internal}
