% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fis_operations.R
\name{fis_list_experiment_target_account_configurations}
\alias{fis_list_experiment_target_account_configurations}
\title{Lists the target account configurations of the specified experiment}
\usage{
fis_list_experiment_target_account_configurations(
  experimentId,
  nextToken = NULL
)
}
\arguments{
\item{experimentId}{[required] The ID of the experiment.}

\item{nextToken}{The token for the next page of results.}
}
\description{
Lists the target account configurations of the specified experiment.

See \url{https://www.paws-r-sdk.com/docs/fis_list_experiment_target_account_configurations/} for full documentation.
}
\keyword{internal}
