% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/codeconnections_operations.R
\name{codeconnections_list_repository_links}
\alias{codeconnections_list_repository_links}
\title{Lists the repository links created for connections in your account}
\usage{
codeconnections_list_repository_links(MaxResults = NULL, NextToken = NULL)
}
\arguments{
\item{MaxResults}{A non-zero, non-negative integer used to limit the number of returned results.}

\item{NextToken}{An enumeration token that, when provided in a request, returns the next batch of the results.}
}
\description{
Lists the repository links created for connections in your account.

See \url{https://www.paws-r-sdk.com/docs/codeconnections_list_repository_links/} for full documentation.
}
\keyword{internal}
